constant

package
v0.0.0-...-31d149e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2026 License: GPL-3.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

const (
	MetricUpdatesTotal     = "upda_updates_all"
	MetricUpdatesTotalHelp = "amount of all updates"

	MetricUpdatesByState      = "upda_updates_by_state"
	MetricUpdatesByStateHelp  = "amount of updates per state"
	MetricUpdatesByStateLabel = "state"

	MetricWebhooks     = "upda_webhooks"
	MetricWebhooksHelp = "amount of all webhooks"

	MetricEvents     = "upda_events"
	MetricEventsHelp = "amount of all events"

	MetricActions     = "upda_actions"
	MetricActionsHelp = "amount of all actions"
)

Variables

var ErrInvalidActionInvocationState = fmt.Errorf("not a valid ActionInvocationState, try [%s]", strings.Join(_ActionInvocationStateNames, ", "))
var ErrInvalidActionType = fmt.Errorf("not a valid ActionType, try [%s]", strings.Join(_ActionTypeNames, ", "))
var ErrInvalidConfigAuthSessionProvider = fmt.Errorf("not a valid ConfigAuthSessionProvider, try [%s]", strings.Join(_ConfigAuthSessionProviderNames, ", "))
var ErrInvalidConfigAuthSessionSameSite = fmt.Errorf("not a valid ConfigAuthSessionSameSite, try [%s]", strings.Join(_ConfigAuthSessionSameSiteNames, ", "))
var ErrInvalidConfigAuthType = fmt.Errorf("not a valid ConfigAuthType, try [%s]", strings.Join(_ConfigAuthTypeNames, ", "))
var ErrInvalidConfigDatabaseType = fmt.Errorf("not a valid ConfigDatabaseType, try [%s]", strings.Join(_ConfigDatabaseTypeNames, ", "))
var ErrInvalidConfigLogEncoding = fmt.Errorf("not a valid ConfigLogEncoding, try [%s]", strings.Join(_ConfigLogEncodingNames, ", "))
var ErrInvalidConfigLogTimeEncoder = fmt.Errorf("not a valid ConfigLogTimeEncoder, try [%s]", strings.Join(_ConfigLogTimeEncoderNames, ", "))
var ErrInvalidEventName = fmt.Errorf("not a valid EventName, try [%s]", strings.Join(_EventNameNames, ", "))
var ErrInvalidEventState = fmt.Errorf("not a valid EventState, try [%s]", strings.Join(_EventStateNames, ", "))
var ErrInvalidFilterPresetType = fmt.Errorf("not a valid FilterPresetType, try [%s]", strings.Join(_FilterPresetTypeNames, ", "))
var ErrInvalidWebhookType = fmt.Errorf("not a valid WebhookType, try [%s]", strings.Join(_WebhookTypeNames, ", "))

Functions

func ActionInvocationStateNames

func ActionInvocationStateNames() []string

ActionInvocationStateNames returns a list of possible string values of ActionInvocationState.

func ActionTypeNames

func ActionTypeNames() []string

ActionTypeNames returns a list of possible string values of ActionType.

func ConfigAuthSessionProviderNames

func ConfigAuthSessionProviderNames() []string

ConfigAuthSessionProviderNames returns a list of possible string values of ConfigAuthSessionProvider.

func ConfigAuthSessionSameSiteNames

func ConfigAuthSessionSameSiteNames() []string

ConfigAuthSessionSameSiteNames returns a list of possible string values of ConfigAuthSessionSameSite.

func ConfigAuthTypeNames

func ConfigAuthTypeNames() []string

ConfigAuthTypeNames returns a list of possible string values of ConfigAuthType.

func ConfigDatabaseTypeNames

func ConfigDatabaseTypeNames() []string

ConfigDatabaseTypeNames returns a list of possible string values of ConfigDatabaseType.

func ConfigLogEncodingNames

func ConfigLogEncodingNames() []string

ConfigLogEncodingNames returns a list of possible string values of ConfigLogEncoding.

func ConfigLogTimeEncoderNames

func ConfigLogTimeEncoderNames() []string

ConfigLogTimeEncoderNames returns a list of possible string values of ConfigLogTimeEncoder.

func EventNameNames

func EventNameNames() []string

EventNameNames returns a list of possible string values of EventName.

func EventStateNames

func EventStateNames() []string

EventStateNames returns a list of possible string values of EventState.

func FilterPresetTypeNames

func FilterPresetTypeNames() []string

FilterPresetTypeNames returns a list of possible string values of FilterPresetType.

func FromVariadicToStr

func FromVariadicToStr[T ~string](s ...T) []string

FromVariadicToStr converts variadic notation to string array if type is of string

func WebhookTypeNames

func WebhookTypeNames() []string

WebhookTypeNames returns a list of possible string values of WebhookType.

Types

type ActionInvocationState

type ActionInvocationState string

ENUM(created, running, retrying, success, error)

const (
	// ActionInvocationStateCreated is a ActionInvocationState of type created.
	ActionInvocationStateCreated ActionInvocationState = "created"
	// ActionInvocationStateRunning is a ActionInvocationState of type running.
	ActionInvocationStateRunning ActionInvocationState = "running"
	// ActionInvocationStateRetrying is a ActionInvocationState of type retrying.
	ActionInvocationStateRetrying ActionInvocationState = "retrying"
	// ActionInvocationStateSuccess is a ActionInvocationState of type success.
	ActionInvocationStateSuccess ActionInvocationState = "success"
	// ActionInvocationStateError is a ActionInvocationState of type error.
	ActionInvocationStateError ActionInvocationState = "error"
)

func ActionInvocationStateValues

func ActionInvocationStateValues() []ActionInvocationState

ActionInvocationStateValues returns a list of the values for ActionInvocationState

func MustParseActionInvocationState

func MustParseActionInvocationState(name string) ActionInvocationState

MustParseActionInvocationState converts a string to a ActionInvocationState, and panics if is not valid.

func ParseActionInvocationState

func ParseActionInvocationState(name string) (ActionInvocationState, error)

ParseActionInvocationState attempts to convert a string to a ActionInvocationState.

func (*ActionInvocationState) AppendText

func (x *ActionInvocationState) AppendText(b []byte) ([]byte, error)

AppendText appends the textual representation of itself to the end of b (allocating a larger slice if necessary) and returns the updated slice.

Implementations must not retain b, nor mutate any bytes within b[:len(b)].

func (ActionInvocationState) IsValid

func (x ActionInvocationState) IsValid() bool

IsValid provides a quick way to determine if the typed value is part of the allowed enumerated values

func (ActionInvocationState) MarshalText

func (x ActionInvocationState) MarshalText() ([]byte, error)

MarshalText implements the text marshaller method.

func (ActionInvocationState) String

func (x ActionInvocationState) String() string

String implements the Stringer interface.

func (*ActionInvocationState) UnmarshalText

func (x *ActionInvocationState) UnmarshalText(text []byte) error

UnmarshalText implements the text unmarshaller method.

type ActionType

type ActionType string

ENUM(shoutrrr)

const (
	// ActionTypeShoutrrr is a ActionType of type shoutrrr.
	ActionTypeShoutrrr ActionType = "shoutrrr"
)

func ActionTypeValues

func ActionTypeValues() []ActionType

ActionTypeValues returns a list of the values for ActionType

func MustParseActionType

func MustParseActionType(name string) ActionType

MustParseActionType converts a string to a ActionType, and panics if is not valid.

func ParseActionType

func ParseActionType(name string) (ActionType, error)

ParseActionType attempts to convert a string to a ActionType.

func (*ActionType) AppendText

func (x *ActionType) AppendText(b []byte) ([]byte, error)

AppendText appends the textual representation of itself to the end of b (allocating a larger slice if necessary) and returns the updated slice.

Implementations must not retain b, nor mutate any bytes within b[:len(b)].

func (ActionType) IsValid

func (x ActionType) IsValid() bool

IsValid provides a quick way to determine if the typed value is part of the allowed enumerated values

func (ActionType) MarshalText

func (x ActionType) MarshalText() ([]byte, error)

MarshalText implements the text marshaller method.

func (ActionType) String

func (x ActionType) String() string

String implements the Stringer interface.

func (*ActionType) UnmarshalText

func (x *ActionType) UnmarshalText(text []byte) error

UnmarshalText implements the text unmarshaller method.

type ConfigAuthSessionProvider

type ConfigAuthSessionProvider string

ENUM(single, credentials)

const (
	// ConfigAuthSessionProviderSingle is a ConfigAuthSessionProvider of type single.
	ConfigAuthSessionProviderSingle ConfigAuthSessionProvider = "single"
	// ConfigAuthSessionProviderCredentials is a ConfigAuthSessionProvider of type credentials.
	ConfigAuthSessionProviderCredentials ConfigAuthSessionProvider = "credentials"
)

func ConfigAuthSessionProviderValues

func ConfigAuthSessionProviderValues() []ConfigAuthSessionProvider

ConfigAuthSessionProviderValues returns a list of the values for ConfigAuthSessionProvider

func MustParseConfigAuthSessionProvider

func MustParseConfigAuthSessionProvider(name string) ConfigAuthSessionProvider

MustParseConfigAuthSessionProvider converts a string to a ConfigAuthSessionProvider, and panics if is not valid.

func ParseConfigAuthSessionProvider

func ParseConfigAuthSessionProvider(name string) (ConfigAuthSessionProvider, error)

ParseConfigAuthSessionProvider attempts to convert a string to a ConfigAuthSessionProvider.

func (*ConfigAuthSessionProvider) AppendText

func (x *ConfigAuthSessionProvider) AppendText(b []byte) ([]byte, error)

AppendText appends the textual representation of itself to the end of b (allocating a larger slice if necessary) and returns the updated slice.

Implementations must not retain b, nor mutate any bytes within b[:len(b)].

func (ConfigAuthSessionProvider) IsValid

func (x ConfigAuthSessionProvider) IsValid() bool

IsValid provides a quick way to determine if the typed value is part of the allowed enumerated values

func (ConfigAuthSessionProvider) MarshalText

func (x ConfigAuthSessionProvider) MarshalText() ([]byte, error)

MarshalText implements the text marshaller method.

func (ConfigAuthSessionProvider) String

func (x ConfigAuthSessionProvider) String() string

String implements the Stringer interface.

func (*ConfigAuthSessionProvider) UnmarshalText

func (x *ConfigAuthSessionProvider) UnmarshalText(text []byte) error

UnmarshalText implements the text unmarshaller method.

type ConfigAuthSessionSameSite

type ConfigAuthSessionSameSite string

ENUM(lax, strict)

const (
	// ConfigAuthSessionSameSiteLax is a ConfigAuthSessionSameSite of type lax.
	ConfigAuthSessionSameSiteLax ConfigAuthSessionSameSite = "lax"
	// ConfigAuthSessionSameSiteStrict is a ConfigAuthSessionSameSite of type strict.
	ConfigAuthSessionSameSiteStrict ConfigAuthSessionSameSite = "strict"
)

func ConfigAuthSessionSameSiteValues

func ConfigAuthSessionSameSiteValues() []ConfigAuthSessionSameSite

ConfigAuthSessionSameSiteValues returns a list of the values for ConfigAuthSessionSameSite

func MustParseConfigAuthSessionSameSite

func MustParseConfigAuthSessionSameSite(name string) ConfigAuthSessionSameSite

MustParseConfigAuthSessionSameSite converts a string to a ConfigAuthSessionSameSite, and panics if is not valid.

func ParseConfigAuthSessionSameSite

func ParseConfigAuthSessionSameSite(name string) (ConfigAuthSessionSameSite, error)

ParseConfigAuthSessionSameSite attempts to convert a string to a ConfigAuthSessionSameSite.

func (*ConfigAuthSessionSameSite) AppendText

func (x *ConfigAuthSessionSameSite) AppendText(b []byte) ([]byte, error)

AppendText appends the textual representation of itself to the end of b (allocating a larger slice if necessary) and returns the updated slice.

Implementations must not retain b, nor mutate any bytes within b[:len(b)].

func (ConfigAuthSessionSameSite) IsValid

func (x ConfigAuthSessionSameSite) IsValid() bool

IsValid provides a quick way to determine if the typed value is part of the allowed enumerated values

func (ConfigAuthSessionSameSite) MarshalText

func (x ConfigAuthSessionSameSite) MarshalText() ([]byte, error)

MarshalText implements the text marshaller method.

func (ConfigAuthSessionSameSite) String

func (x ConfigAuthSessionSameSite) String() string

String implements the Stringer interface.

func (*ConfigAuthSessionSameSite) UnmarshalText

func (x *ConfigAuthSessionSameSite) UnmarshalText(text []byte) error

UnmarshalText implements the text unmarshaller method.

type ConfigAuthType

type ConfigAuthType string

ENUM(session)

const (
	// ConfigAuthTypeSession is a ConfigAuthType of type session.
	ConfigAuthTypeSession ConfigAuthType = "session"
)

func ConfigAuthTypeValues

func ConfigAuthTypeValues() []ConfigAuthType

ConfigAuthTypeValues returns a list of the values for ConfigAuthType

func MustParseConfigAuthType

func MustParseConfigAuthType(name string) ConfigAuthType

MustParseConfigAuthType converts a string to a ConfigAuthType, and panics if is not valid.

func ParseConfigAuthType

func ParseConfigAuthType(name string) (ConfigAuthType, error)

ParseConfigAuthType attempts to convert a string to a ConfigAuthType.

func (*ConfigAuthType) AppendText

func (x *ConfigAuthType) AppendText(b []byte) ([]byte, error)

AppendText appends the textual representation of itself to the end of b (allocating a larger slice if necessary) and returns the updated slice.

Implementations must not retain b, nor mutate any bytes within b[:len(b)].

func (ConfigAuthType) IsValid

func (x ConfigAuthType) IsValid() bool

IsValid provides a quick way to determine if the typed value is part of the allowed enumerated values

func (ConfigAuthType) MarshalText

func (x ConfigAuthType) MarshalText() ([]byte, error)

MarshalText implements the text marshaller method.

func (ConfigAuthType) String

func (x ConfigAuthType) String() string

String implements the Stringer interface.

func (*ConfigAuthType) UnmarshalText

func (x *ConfigAuthType) UnmarshalText(text []byte) error

UnmarshalText implements the text unmarshaller method.

type ConfigDatabaseType

type ConfigDatabaseType string

ENUM(postgres)

const (
	// ConfigDatabaseTypePostgres is a ConfigDatabaseType of type postgres.
	ConfigDatabaseTypePostgres ConfigDatabaseType = "postgres"
)

func ConfigDatabaseTypeValues

func ConfigDatabaseTypeValues() []ConfigDatabaseType

ConfigDatabaseTypeValues returns a list of the values for ConfigDatabaseType

func MustParseConfigDatabaseType

func MustParseConfigDatabaseType(name string) ConfigDatabaseType

MustParseConfigDatabaseType converts a string to a ConfigDatabaseType, and panics if is not valid.

func ParseConfigDatabaseType

func ParseConfigDatabaseType(name string) (ConfigDatabaseType, error)

ParseConfigDatabaseType attempts to convert a string to a ConfigDatabaseType.

func (*ConfigDatabaseType) AppendText

func (x *ConfigDatabaseType) AppendText(b []byte) ([]byte, error)

AppendText appends the textual representation of itself to the end of b (allocating a larger slice if necessary) and returns the updated slice.

Implementations must not retain b, nor mutate any bytes within b[:len(b)].

func (ConfigDatabaseType) IsValid

func (x ConfigDatabaseType) IsValid() bool

IsValid provides a quick way to determine if the typed value is part of the allowed enumerated values

func (ConfigDatabaseType) MarshalText

func (x ConfigDatabaseType) MarshalText() ([]byte, error)

MarshalText implements the text marshaller method.

func (ConfigDatabaseType) String

func (x ConfigDatabaseType) String() string

String implements the Stringer interface.

func (*ConfigDatabaseType) UnmarshalText

func (x *ConfigDatabaseType) UnmarshalText(text []byte) error

UnmarshalText implements the text unmarshaller method.

type ConfigLogEncoding

type ConfigLogEncoding string

ENUM(json, console)

const (
	// ConfigLogEncodingJson is a ConfigLogEncoding of type json.
	ConfigLogEncodingJson ConfigLogEncoding = "json"
	// ConfigLogEncodingConsole is a ConfigLogEncoding of type console.
	ConfigLogEncodingConsole ConfigLogEncoding = "console"
)

func ConfigLogEncodingValues

func ConfigLogEncodingValues() []ConfigLogEncoding

ConfigLogEncodingValues returns a list of the values for ConfigLogEncoding

func MustParseConfigLogEncoding

func MustParseConfigLogEncoding(name string) ConfigLogEncoding

MustParseConfigLogEncoding converts a string to a ConfigLogEncoding, and panics if is not valid.

func ParseConfigLogEncoding

func ParseConfigLogEncoding(name string) (ConfigLogEncoding, error)

ParseConfigLogEncoding attempts to convert a string to a ConfigLogEncoding.

func (*ConfigLogEncoding) AppendText

func (x *ConfigLogEncoding) AppendText(b []byte) ([]byte, error)

AppendText appends the textual representation of itself to the end of b (allocating a larger slice if necessary) and returns the updated slice.

Implementations must not retain b, nor mutate any bytes within b[:len(b)].

func (ConfigLogEncoding) IsValid

func (x ConfigLogEncoding) IsValid() bool

IsValid provides a quick way to determine if the typed value is part of the allowed enumerated values

func (ConfigLogEncoding) MarshalText

func (x ConfigLogEncoding) MarshalText() ([]byte, error)

MarshalText implements the text marshaller method.

func (ConfigLogEncoding) String

func (x ConfigLogEncoding) String() string

String implements the Stringer interface.

func (*ConfigLogEncoding) UnmarshalText

func (x *ConfigLogEncoding) UnmarshalText(text []byte) error

UnmarshalText implements the text unmarshaller method.

type ConfigLogTimeEncoder

type ConfigLogTimeEncoder string

ENUM(epoch, epochmillis, epochnanos, iso8601, rfc3339, rfc3339nano)

const (
	// ConfigLogTimeEncoderEpoch is a ConfigLogTimeEncoder of type epoch.
	ConfigLogTimeEncoderEpoch ConfigLogTimeEncoder = "epoch"
	// ConfigLogTimeEncoderEpochmillis is a ConfigLogTimeEncoder of type epochmillis.
	ConfigLogTimeEncoderEpochmillis ConfigLogTimeEncoder = "epochmillis"
	// ConfigLogTimeEncoderEpochnanos is a ConfigLogTimeEncoder of type epochnanos.
	ConfigLogTimeEncoderEpochnanos ConfigLogTimeEncoder = "epochnanos"
	// ConfigLogTimeEncoderIso8601 is a ConfigLogTimeEncoder of type iso8601.
	ConfigLogTimeEncoderIso8601 ConfigLogTimeEncoder = "iso8601"
	// ConfigLogTimeEncoderRfc3339 is a ConfigLogTimeEncoder of type rfc3339.
	ConfigLogTimeEncoderRfc3339 ConfigLogTimeEncoder = "rfc3339"
	// ConfigLogTimeEncoderRfc3339nano is a ConfigLogTimeEncoder of type rfc3339nano.
	ConfigLogTimeEncoderRfc3339nano ConfigLogTimeEncoder = "rfc3339nano"
)

func ConfigLogTimeEncoderValues

func ConfigLogTimeEncoderValues() []ConfigLogTimeEncoder

ConfigLogTimeEncoderValues returns a list of the values for ConfigLogTimeEncoder

func MustParseConfigLogTimeEncoder

func MustParseConfigLogTimeEncoder(name string) ConfigLogTimeEncoder

MustParseConfigLogTimeEncoder converts a string to a ConfigLogTimeEncoder, and panics if is not valid.

func ParseConfigLogTimeEncoder

func ParseConfigLogTimeEncoder(name string) (ConfigLogTimeEncoder, error)

ParseConfigLogTimeEncoder attempts to convert a string to a ConfigLogTimeEncoder.

func (*ConfigLogTimeEncoder) AppendText

func (x *ConfigLogTimeEncoder) AppendText(b []byte) ([]byte, error)

AppendText appends the textual representation of itself to the end of b (allocating a larger slice if necessary) and returns the updated slice.

Implementations must not retain b, nor mutate any bytes within b[:len(b)].

func (ConfigLogTimeEncoder) IsValid

func (x ConfigLogTimeEncoder) IsValid() bool

IsValid provides a quick way to determine if the typed value is part of the allowed enumerated values

func (ConfigLogTimeEncoder) MarshalText

func (x ConfigLogTimeEncoder) MarshalText() ([]byte, error)

MarshalText implements the text marshaller method.

func (ConfigLogTimeEncoder) String

func (x ConfigLogTimeEncoder) String() string

String implements the Stringer interface.

func (*ConfigLogTimeEncoder) UnmarshalText

func (x *ConfigLogTimeEncoder) UnmarshalText(text []byte) error

UnmarshalText implements the text unmarshaller method.

type EventName

type EventName string

ENUM(update_created, update_updated, update_updated_state, update_updated_version, update_deleted, comment_created)

const (
	// EventNameUpdateCreated is a EventName of type update_created.
	EventNameUpdateCreated EventName = "update_created"
	// EventNameUpdateUpdated is a EventName of type update_updated.
	EventNameUpdateUpdated EventName = "update_updated"
	// EventNameUpdateUpdatedState is a EventName of type update_updated_state.
	EventNameUpdateUpdatedState EventName = "update_updated_state"
	// EventNameUpdateUpdatedVersion is a EventName of type update_updated_version.
	EventNameUpdateUpdatedVersion EventName = "update_updated_version"
	// EventNameUpdateDeleted is a EventName of type update_deleted.
	EventNameUpdateDeleted EventName = "update_deleted"
	// EventNameCommentCreated is a EventName of type comment_created.
	EventNameCommentCreated EventName = "comment_created"
)

func EventNameValues

func EventNameValues() []EventName

EventNameValues returns a list of the values for EventName

func MustParseEventName

func MustParseEventName(name string) EventName

MustParseEventName converts a string to a EventName, and panics if is not valid.

func ParseEventName

func ParseEventName(name string) (EventName, error)

ParseEventName attempts to convert a string to a EventName.

func (*EventName) AppendText

func (x *EventName) AppendText(b []byte) ([]byte, error)

AppendText appends the textual representation of itself to the end of b (allocating a larger slice if necessary) and returns the updated slice.

Implementations must not retain b, nor mutate any bytes within b[:len(b)].

func (EventName) IsValid

func (x EventName) IsValid() bool

IsValid provides a quick way to determine if the typed value is part of the allowed enumerated values

func (EventName) MarshalText

func (x EventName) MarshalText() ([]byte, error)

MarshalText implements the text marshaller method.

func (EventName) String

func (x EventName) String() string

String implements the Stringer interface.

func (*EventName) UnmarshalText

func (x *EventName) UnmarshalText(text []byte) error

UnmarshalText implements the text unmarshaller method.

type EventState

type EventState string

ENUM(created, enqueued)

const (
	// EventStateCreated is a EventState of type created.
	EventStateCreated EventState = "created"
	// EventStateEnqueued is a EventState of type enqueued.
	EventStateEnqueued EventState = "enqueued"
)

func EventStateValues

func EventStateValues() []EventState

EventStateValues returns a list of the values for EventState

func MustParseEventState

func MustParseEventState(name string) EventState

MustParseEventState converts a string to a EventState, and panics if is not valid.

func ParseEventState

func ParseEventState(name string) (EventState, error)

ParseEventState attempts to convert a string to a EventState.

func (*EventState) AppendText

func (x *EventState) AppendText(b []byte) ([]byte, error)

AppendText appends the textual representation of itself to the end of b (allocating a larger slice if necessary) and returns the updated slice.

Implementations must not retain b, nor mutate any bytes within b[:len(b)].

func (EventState) IsValid

func (x EventState) IsValid() bool

IsValid provides a quick way to determine if the typed value is part of the allowed enumerated values

func (EventState) MarshalText

func (x EventState) MarshalText() ([]byte, error)

MarshalText implements the text marshaller method.

func (EventState) String

func (x EventState) String() string

String implements the Stringer interface.

func (*EventState) UnmarshalText

func (x *EventState) UnmarshalText(text []byte) error

UnmarshalText implements the text unmarshaller method.

type FilterPresetType

type FilterPresetType string

ENUM(update)

const (
	// FilterPresetTypeUpdate is a FilterPresetType of type update.
	FilterPresetTypeUpdate FilterPresetType = "update"
)

func FilterPresetTypeValues

func FilterPresetTypeValues() []FilterPresetType

FilterPresetTypeValues returns a list of the values for FilterPresetType

func MustParseFilterPresetType

func MustParseFilterPresetType(name string) FilterPresetType

MustParseFilterPresetType converts a string to a FilterPresetType, and panics if is not valid.

func ParseFilterPresetType

func ParseFilterPresetType(name string) (FilterPresetType, error)

ParseFilterPresetType attempts to convert a string to a FilterPresetType.

func (*FilterPresetType) AppendText

func (x *FilterPresetType) AppendText(b []byte) ([]byte, error)

AppendText appends the textual representation of itself to the end of b (allocating a larger slice if necessary) and returns the updated slice.

Implementations must not retain b, nor mutate any bytes within b[:len(b)].

func (FilterPresetType) IsValid

func (x FilterPresetType) IsValid() bool

IsValid provides a quick way to determine if the typed value is part of the allowed enumerated values

func (FilterPresetType) MarshalText

func (x FilterPresetType) MarshalText() ([]byte, error)

MarshalText implements the text marshaller method.

func (FilterPresetType) String

func (x FilterPresetType) String() string

String implements the Stringer interface.

func (*FilterPresetType) UnmarshalText

func (x *FilterPresetType) UnmarshalText(text []byte) error

UnmarshalText implements the text unmarshaller method.

type WebhookType

type WebhookType string

ENUM(generic, diun)

const (
	// WebhookTypeGeneric is a WebhookType of type generic.
	WebhookTypeGeneric WebhookType = "generic"
	// WebhookTypeDiun is a WebhookType of type diun.
	WebhookTypeDiun WebhookType = "diun"
)

func MustParseWebhookType

func MustParseWebhookType(name string) WebhookType

MustParseWebhookType converts a string to a WebhookType, and panics if is not valid.

func ParseWebhookType

func ParseWebhookType(name string) (WebhookType, error)

ParseWebhookType attempts to convert a string to a WebhookType.

func WebhookTypeValues

func WebhookTypeValues() []WebhookType

WebhookTypeValues returns a list of the values for WebhookType

func (*WebhookType) AppendText

func (x *WebhookType) AppendText(b []byte) ([]byte, error)

AppendText appends the textual representation of itself to the end of b (allocating a larger slice if necessary) and returns the updated slice.

Implementations must not retain b, nor mutate any bytes within b[:len(b)].

func (WebhookType) IsValid

func (x WebhookType) IsValid() bool

IsValid provides a quick way to determine if the typed value is part of the allowed enumerated values

func (WebhookType) MarshalText

func (x WebhookType) MarshalText() ([]byte, error)

MarshalText implements the text marshaller method.

func (WebhookType) String

func (x WebhookType) String() string

String implements the Stringer interface.

func (*WebhookType) UnmarshalText

func (x *WebhookType) UnmarshalText(text []byte) error

UnmarshalText implements the text unmarshaller method.

Jump to